const webpack = require('webpack');
const merge = require('webpack-merge');
const path = require('path');

var commonConfig = {
  module: {
    loaders: [
      {
        test: /\.js$/,
        loader: 'babel-loader',
        include: __dirname,
        exclude: /node_modules/
      },
      {
        test: /\.vue$/,
        loader: 'vue-loader'
      },
      {
        test: /\.css$/,
        loader: 'style!less!css'
      }
    ]
  },
  plugins: [
    new webpack.optimize.UglifyJsPlugin({
      minimize: true,
      sourceMap: false,
      mangle: true,
      compress: {
        warnings: false
      }
    })
  ],
  externals: {
    vue: 'vue',
    lodash: 'lodash'
  }
};

module.exports = [
  // browser
  merge(commonConfig, {
    entry: path.resolve(__dirname + '/src/plugin.js'),
    output: {
      filename: './dist/vue-dualist.min.js',
      libraryTarget: 'window',
      library: 'Dualist'
    }
  }),
  // node
  merge(commonConfig, {
    entry: path.resolve(__dirname + '/src/DualistComponent.vue'),
    output: {
      filename: './dist/vue-dualist.js',
      libraryTarget: 'umd',
      library: 'vue-dualist',
      umdNamedDefine: true
    }
  })
]
